@@ -1,7 +1,7 @@
 """AwesomeVersion."""
 from __future__ import annotations
 
-from typing import Any
+from typing import TYPE_CHECKING, Any, Dict
 from warnings import warn
 
 from .comparehandlers.container import compare_handler_container
@@ -15,7 +15,6 @@ from .strategy import (
     AwesomeVersionStrategy,
     AwesomeVersionStrategyDescription,
 )
-from .typing import EnsureStrategyIterableType, EnsureStrategyType, VersionType
 from .utils.regex import (
     RE_DIGIT,
     RE_MODIFIER,
@@ -24,6 +23,9 @@ from .utils.regex import (
     generate_full_string_regex,
 )
 
+if TYPE_CHECKING:
+    from .typing import EnsureStrategyIterableType, EnsureStrategyType, VersionType
+
 
 class _AwesomeVersionBase(str):
     """Base class for AwesomeVersion to allow the usage of the default JSON encoder."""
@@ -202,6 +204,25 @@ class AwesomeVersion(_AwesomeVersionBase):
     def __ge__(self, compareto: object) -> bool:
         return self.__eq__(compareto) or self.__gt__(compareto)
 
+    def __sub__(self, compareto: object) -> AwesomeVersionDiff:
+        return self.diff(compareto)
+
+    def diff(self, compareto: VersionType) -> AwesomeVersionDiff:
+        """Return a dictionary with differences between 2 AwesomeVersion objects."""
+        if isinstance(compareto, (str, float, int)):
+            compareto = AwesomeVersion(compareto)
+        if not isinstance(compareto, AwesomeVersion):
+            raise AwesomeVersionCompareException("Not a valid AwesomeVersion object")
+        return AwesomeVersionDiff(
+            {
+                "major": self.major != compareto.major,
+                "minor": self.minor != compareto.minor,
+                "patch": self.patch != compareto.patch,
+                "modifier": self.modifier != compareto.modifier,
+                "strategy": self.strategy != compareto.strategy,
+            }
+        )
+
     def section(self, idx: int) -> int:
         """Return the value of the specified section of the version."""
         if self.sections >= (idx + 1):
@@ -291,11 +312,12 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the major version.
 
-        Will return None if the versions is not semver/buildver/simplever.
+        Will return None if the versions is not semver/buildver/calver/simplever.
         """
         if self.strategy not in (
             AwesomeVersionStrategy.SEMVER,
             AwesomeVersionStrategy.BUILDVER,
+            AwesomeVersionStrategy.CALVER,
             AwesomeVersionStrategy.SIMPLEVER,
         ):
             return None
@@ -306,11 +328,12 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the minor version.
 
-        Will return None if the versions is not semver/simplever
+        Will return None if the versions is not semver/simplever/calver
         Will return None if the version does not have at least 2 sections.
         """
         if self.strategy not in (
             AwesomeVersionStrategy.SEMVER,
+            AwesomeVersionStrategy.CALVER,
             AwesomeVersionStrategy.SIMPLEVER,
         ):
             return None
@@ -322,13 +345,14 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the patch version.
 
-        Will return None if the versions is not semver/simplever
+        Will return None if the versions is not semver/simplever/calver
         Will return None if the version does not have at least 3 sections.
         """
         if (
             self.strategy
             not in (
                 AwesomeVersionStrategy.SEMVER,
+                AwesomeVersionStrategy.CALVER,
                 AwesomeVersionStrategy.SIMPLEVER,
             )
             or self.sections < 3
@@ -336,6 +360,16 @@ class AwesomeVersion(_AwesomeVersionBase):
             return None
         return AwesomeVersion(self.section(2))
 
+    @property
+    def micro(self) -> AwesomeVersion | None:
+        """Alias to self.patch"""
+        return self.patch
+
+    @property
+    def year(self) -> AwesomeVersion | None:
+        """Alias to self.major, here to provide a better name for use in CalVer."""
+        return self.major
+
     @property
     def valid(self) -> bool:
         """Return True if the version is not UNKNOWN."""
@@ -417,3 +451,42 @@ class AwesomeVersion(_AwesomeVersionBase):
                 generate_full_string_regex(RE_SIMPLE).match(self.string) is not None
             )
         return self._simple
+
+
+class AwesomeVersionDiff:
+    """Structured output of AwesomeVersion.diff"""
+
+    def __init__(self, changes: Dict[str, bool]) -> None:
+        """Initialize the AwesomeVersionDiff."""
+        self._changes = changes
+
+    def __repr__(self) -> str:
+        return (
+            f"AwesomeVersionDiff(major={self.major}, minor={self.minor}, "
+            f"patch={self.patch}, modifier={self.modifier}, strategy={self.strategy})"
+        )
+
+    @property
+    def major(self) -> bool:
+        """Return True if the major version has changed."""
+        return self._changes["major"]
+
+    @property
+    def minor(self) -> bool:
+        """Return True if the minor version has changed."""
+        return self._changes["minor"]
+
+    @property
+    def patch(self) -> bool:
+        """Return True if the patch version has changed."""
+        return self._changes["patch"]
+
+    @property
+    def modifier(self) -> bool:
+        """Return True if the modifier version has changed."""
+        return self._changes["modifier"]
+
+    @property
+    def strategy(self) -> bool:
+        """Return True if the strategy has changed."""
+        return self._changes["strategy"]
