@@ -1,5 +1,7 @@
 """Special handler for container."""
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from ..strategy import AwesomeVersionStrategy
 
@@ -10,9 +12,9 @@ if TYPE_CHECKING:
 
 
 def compare_handler_container(
-    version_a: "AwesomeVersion",
-    version_b: "AwesomeVersion",
-) -> Optional[bool]:
+    version_a: AwesomeVersion,
+    version_b: AwesomeVersion,
+) -> bool | None:
     """Compare handler container."""
     if version_a.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
         if version_b.strategy != AwesomeVersionStrategy.SPECIALCONTAINER:
